@@ -1,35 +1,43 @@
 mod accessor;
+mod bag;
 mod carve;
 mod collect;
+mod combine;
+mod contract_action;
+mod contract_cancel;
+mod contract_create;
+mod contract_get;
+mod contract_summary;
+mod delete_wallet;
+mod deposit;
+mod history;
+mod reconcile;
+mod transfer;
 mod wallet_summary;
 mod withdraw;
-mod transfer;
-mod deposit;
-mod delete_wallet;
-mod history;
-mod contract_create;
-mod contract_summary;
-mod contract_get;
-mod contract_cancel;
-mod contract_action;
-mod reconcile;
-mod bag;
-mod combine;
+mod instance_create;
+mod instance_summary;
+mod instance_action;
+mod instance_client;
 
 pub use accessor::*;
+pub use bag::*;
 pub use carve::*;
 pub use collect::*;
+pub use combine::*;
+pub use contract_action::*;
+pub use contract_cancel::*;
+pub use contract_create::*;
+pub use contract_get::*;
+pub use contract_summary::*;
+pub use delete_wallet::*;
+pub use deposit::*;
+pub use history::*;
+pub use reconcile::*;
+pub use transfer::*;
 pub use wallet_summary::*;
 pub use withdraw::*;
-pub use transfer::*;
-pub use deposit::*;
-pub use delete_wallet::*;
-pub use history::*;
-pub use contract_create::*;
-pub use contract_summary::*;
-pub use contract_get::*;
-pub use contract_cancel::*;
-pub use contract_action::*;
-pub use reconcile::*;
-pub use bag::*;
-pub use combine::*;
\ No newline at end of file
+pub use instance_create::*;
+pub use instance_summary::*;
+pub use instance_action::*;
+pub use instance_client::*;
\ No newline at end of file
