@@ -1,6 +1,6 @@
-#[allow(unused_imports)]
-use tracing::{info, error, debug, trace, warn};
 use std::sync::Arc;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, trace, warn};
 use url::Url;
 
 use ate::prelude::*;
@@ -9,11 +9,17 @@ use crate::error::*;
 use crate::model::*;
 use crate::request::*;
 
-pub async fn coin_carve_command(registry: &Arc<Registry>, owner: Ownership, coin: PrimaryKey, needed_denomination: Decimal, new_token: EncryptKey, auth: Url) -> Result<CoinCarveResponse, CoinError>
-{
+pub async fn coin_carve_command(
+    registry: &Arc<Registry>,
+    owner: Ownership,
+    coin: PrimaryKey,
+    needed_denomination: Decimal,
+    new_token: EncryptKey,
+    auth: Url,
+) -> Result<CoinCarveResponse, CoinError> {
     // Open a command chain
     let chain = registry.open_cmd(&auth).await?;
-    
+
     // Create the login command
     let query = CoinCarveRequest {
         owner,
@@ -26,4 +32,4 @@ pub async fn coin_carve_command(registry: &Arc<Registry>, owner: Ownership, coin
     let response: Result<CoinCarveResponse, CoinCarveFailed> = chain.invoke(query).await?;
     let result = response?;
     Ok(result)
-}
\ No newline at end of file
+}
