@@ -1,6 +1,6 @@
-#[allow(unused_imports)]
-use tracing::{info, error, debug, trace, warn};
 use std::sync::Arc;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, trace, warn};
 use url::Url;
 
 use ate::prelude::*;
@@ -9,18 +9,19 @@ use crate::error::*;
 use crate::model::*;
 use crate::request::*;
 
-pub async fn coin_collect_command(registry: &Arc<Registry>, coin_ancestors: Vec<Ownership>, auth: Url) -> Result<CoinCollectResponse, CoinError>
-{
+pub async fn coin_collect_command(
+    registry: &Arc<Registry>,
+    coin_ancestors: Vec<Ownership>,
+    auth: Url,
+) -> Result<CoinCollectResponse, CoinError> {
     // Open a command chain
     let chain = registry.open_cmd(&auth).await?;
-    
+
     // Create the login command
-    let query = CoinCollectRequest {
-        coin_ancestors,
-    };
+    let query = CoinCollectRequest { coin_ancestors };
 
     // Attempt the login request with a 10 second timeout
     let response: Result<CoinCollectResponse, CoinCollectFailed> = chain.invoke(query).await?;
     let result = response?;
     Ok(result)
-}
\ No newline at end of file
+}
