@@ -1,5 +1,5 @@
 #[allow(unused_imports)]
-use tracing::{info, error, debug, trace, warn};
+use tracing::{debug, error, info, trace, warn};
 use url::Url;
 
 use crate::error::*;
@@ -7,9 +7,12 @@ use crate::opt::*;
 
 use super::*;
 
-pub async fn main_opts_contract(opts: OptsContractFor, token_path: String, auth_url: Url) -> Result<(), ContractError>
-{
-    let mut context = PurposeContext::new(&opts, token_path.as_str(), &auth_url, true).await?;
+pub async fn main_opts_contract(
+    opts: OptsContractFor,
+    token_path: String,
+    auth_url: Url,
+) -> Result<(), ContractError> {
+    let mut context = PurposeContext::new(&opts, token_path.as_str(), &auth_url, None, true).await?;
     let identity = context.identity.clone();
 
     match context.action.clone() {
@@ -26,4 +29,4 @@ pub async fn main_opts_contract(opts: OptsContractFor, token_path: String, auth_
 
     context.api.commit().await?;
     Ok(())
-}
\ No newline at end of file
+}
