@@ -1,14 +1,14 @@
-#[allow(unused_imports)]
-use tracing::{info, error, debug, trace, warn};
 use std::sync::Arc;
+#[allow(unused_imports)]
+use tracing::{debug, error, info, trace, warn};
 use url::Url;
 
 use ate::prelude::*;
 
 use crate::error::*;
+use crate::helper::*;
 use crate::model::*;
 use crate::request::*;
-use crate::helper::*;
 
 pub async fn contract_create_command(
     registry: &Arc<Registry>,
@@ -20,27 +20,32 @@ pub async fn contract_create_command(
     consumer_wallet: PrimaryKey,
     broker_key: PublicEncryptedSecureData<EncryptKey>,
     broker_unlock_key: EncryptKey,
-) -> Result<ContractCreateResponse, ContractError>
-{
+    force: bool
+) -> Result<ContractCreateResponse, ContractError> {
     // Open a command chain
     let chain = registry.open_cmd(&auth).await?;
 
-    // Now contract the request to create the contract
+    // Now build the request to create the contract
     let sign_key = session_sign_key(session, identity.contains("@"))?;
     let contract_create = ContractCreateRequest {
         consumer_identity: identity,
-        params: SignedProtectedData::new(sign_key, ContractCreateRequestParams {
-            service_code,
-            gst_country,
-            consumer_wallet,
-            broker_unlock_key,
-            broker_key,
-            limited_duration: None,
-        })?,
+        params: SignedProtectedData::new(
+            sign_key,
+            ContractCreateRequestParams {
+                service_code,
+                gst_country,
+                consumer_wallet,
+                broker_unlock_key,
+                broker_key,
+                force,
+                limited_duration: None,
+            },
+        )?,
     };
 
     // Attempt the create contract request
-    let response: Result<ContractCreateResponse, ContractCreateFailed> = chain.invoke(contract_create).await?;
+    let response: Result<ContractCreateResponse, ContractCreateFailed> =
+        chain.invoke(contract_create).await?;
     let result = response?;
     Ok(result)
-}
\ No newline at end of file
+}
