@@ -1,49 +1,51 @@
-mod core;
-mod contract;
-mod contract_cancel;
-mod contract_details;
-mod contract_list;
-mod contract_action;
-mod contract_elevate;
-mod contract_create;
+mod balance;
+mod cancel_deposit;
 mod coin_carve;
 mod coin_collect;
 mod coin_combine;
 mod coin_rotate;
+mod contract;
+mod contract_action;
+mod contract_cancel;
+mod contract_create;
+mod contract_details;
+mod contract_elevate;
+mod contract_list;
+mod core;
 mod deposit;
-mod cancel_deposit;
-mod withdraw;
-mod wallet;
-mod balance;
 mod history;
-mod transfer;
-mod service;
-mod service_find;
 mod login;
 mod logout;
+mod service;
+mod service_find;
+mod transfer;
+mod wallet;
+mod withdraw;
+mod instance;
 
 pub use ate_auth::cmd::*;
 
 pub use self::core::*;
-pub use contract::*;
-pub use contract_cancel::*;
-pub use contract_details::*;
-pub use contract_list::*;
-pub use contract_action::*;
-pub use contract_elevate::*;
-pub use contract_create::*;
+pub use balance::*;
+pub use cancel_deposit::*;
 pub use coin_carve::*;
 pub use coin_collect::*;
 pub use coin_combine::*;
 pub use coin_rotate::*;
+pub use contract::*;
+pub use contract_action::*;
+pub use contract_cancel::*;
+pub use contract_create::*;
+pub use contract_details::*;
+pub use contract_elevate::*;
+pub use contract_list::*;
 pub use deposit::*;
-pub use cancel_deposit::*;
-pub use withdraw::*;
-pub use wallet::*;
-pub use balance::*;
 pub use history::*;
-pub use transfer::*;
+pub use login::*;
+pub use logout::*;
 pub use service::*;
 pub use service_find::*;
-pub use login::*;
-pub use logout::*;
\ No newline at end of file
+pub use transfer::*;
+pub use wallet::*;
+pub use withdraw::*;
+pub use instance::*;
\ No newline at end of file
