@@ -7,8 +7,7 @@ use super::*;
 /// on the market interaction interface. This metadata helps users
 /// identify what they are subscribing for.
 #[derive(Serialize, Deserialize, Debug, Clone)]
-pub struct AdvertisedService
-{
+pub struct AdvertisedService {
     /// Code assigned to this service
     pub code: String,
     /// The name of the service as seen by all consumers
@@ -27,4 +26,4 @@ pub struct AdvertisedService
     pub grace_period: Duration,
     /// The subscription may still have some throttles
     pub throttle: Option<ThrottleTriggers>,
-}
\ No newline at end of file
+}
