@@ -1,13 +1,12 @@
-use serde::*;
 use ate::prelude::*;
+use serde::*;
 
 use super::*;
 
 #[derive(Debug, Serialize, Deserialize, Clone)]
-pub struct CarvedCoin
-{
+pub struct CarvedCoin {
     pub value: Decimal,
     pub currency: NationalCurrency,
     pub coin: PrimaryKey,
-    pub owner: Ownership
-}
\ No newline at end of file
+    pub owner: Ownership,
+}
