@@ -7,10 +7,9 @@ use super::*;
 /// used in a person of groups wallet so that they can access a
 /// particular asset or redeem it
 #[derive(Serialize, Deserialize, Debug, Clone, PartialEq, Eq, PartialOrd, Ord, Hash)]
-pub struct Ownership
-{
+pub struct Ownership {
     pub kind: CommodityKind,
     pub chain: ChainKey,
     pub what: PrimaryKey,
     pub token: EncryptKey,
-}
\ No newline at end of file
+}
