@@ -9,8 +9,7 @@ use super::*;
 /// achieved by proving ownership of the wallet itself. Attaching
 /// the wallet is done by making it a child of user/group.
 #[derive(Serialize, Deserialize, Debug, Clone)]
-pub struct Wallet
-{
+pub struct Wallet {
     /// Name that can be associated with the wallet for organization purposes (default=default)
     pub name: String,
     /// The country you are resident in for tax purposes
@@ -27,4 +26,4 @@ pub struct Wallet
     /// The broker unlock key needs to be supplied in order to access the broker key
     /// (this one is given to the broker key - which makes creates the trust trinity)
     pub broker_unlock_key: EncryptKey,
-}
\ No newline at end of file
+}
