@@ -1,12 +1,11 @@
 use clap::Parser;
 
-use crate::model::NationalCurrency;
 use crate::model::Decimal;
+use crate::model::NationalCurrency;
 
 #[derive(Parser, Clone)]
 #[clap()]
-pub struct OptsDepositPending {
-}
+pub struct OptsDepositPending {}
 
 #[derive(Parser, Clone)]
 #[clap()]
@@ -45,4 +44,4 @@ pub enum OptsDepositAction {
 pub struct OptsDeposit {
     #[clap(subcommand)]
     pub action: OptsDepositAction,
-}
\ No newline at end of file
+}
