@@ -3,5 +3,4 @@ use clap::Parser;
 #[allow(dead_code)]
 #[derive(Parser)]
 #[clap(version = "1.5", author = "Tokera Pty Ltd <info@tokera.com>")]
-pub struct OptsLogout {
-}
\ No newline at end of file
+pub struct OptsLogout {}
