@@ -1,35 +1,39 @@
-mod purpose;
-mod contract;
-mod wallet_action;
 mod balance;
-mod history;
-mod transfer;
-mod source;
-mod destination;
-mod deposit;
-mod withdraw;
-mod remove_wallet;
+mod bus;
+mod contract;
 mod create_wallet;
-mod service;
+mod deposit;
+mod destination;
+mod history;
 mod login;
 mod logout;
+mod purpose;
+mod remove_wallet;
+mod service;
+mod source;
+mod transfer;
 mod wallet;
+mod wallet_action;
+mod withdraw;
+mod instance;
 
 pub use ate_auth::opt::*;
 
-pub use purpose::*;
-pub use contract::*;
-pub use wallet_action::*;
 pub use balance::*;
-pub use history::*;
-pub use transfer::*;
-pub use source::*;
-pub use destination::*;
-pub use deposit::*;
-pub use withdraw::*;
-pub use remove_wallet::*;
+pub use bus::*;
+pub use contract::*;
 pub use create_wallet::*;
-pub use service::*;
+pub use deposit::*;
+pub use destination::*;
+pub use history::*;
 pub use login::*;
 pub use logout::*;
-pub use wallet::*;
\ No newline at end of file
+pub use purpose::*;
+pub use remove_wallet::*;
+pub use service::*;
+pub use source::*;
+pub use transfer::*;
+pub use wallet::*;
+pub use wallet_action::*;
+pub use withdraw::*;
+pub use instance::*;
\ No newline at end of file
