@@ -1,10 +1,9 @@
+use crate::model::*;
 use ate::crypto::SignedProtectedData;
 use serde::*;
-use crate::model::*;
 
 #[derive(Debug, Serialize, Deserialize, Clone)]
-pub struct CoinProofInner
-{
+pub struct CoinProofInner {
     /// Amount to be deposited into this account
     pub amount: Decimal,
     /// National currency to be deposited into this account (e.g. aud,eur,gbp,usd,hkd)
@@ -14,8 +13,7 @@ pub struct CoinProofInner
 }
 
 #[derive(Debug, Serialize, Deserialize, Clone)]
-pub struct CoinProof
-{
+pub struct CoinProof {
     /// Proof that the caller has write access to the account specified
     pub inner: SignedProtectedData<CoinProofInner>,
-}
\ No newline at end of file
+}
